contactMatrixAgeSchool: Calculate a contact matrix for age groups and schools

View source: R/contactMatrixAgeSchool.R

contactMatrixAgeSchoolR Documentation

Calculate a contact matrix for age groups and schools

Description

Calculate a contact matrix for age groups and schools

Usage

contactMatrixAgeSchool(
  agelims,
  agepops,
  schoolagegroups,
  schoolpops,
  schportion
)

Arguments

agelims

minimum age in years for each age group

agepops

population size of each age group

schoolagegroups

index of the age group covered by each school

schoolpops

population size of each school

schportion

portion of within-age-group contacts that are exclusively within school

Value

a square matrix with the contact rate of each group (row) with members of each other group (column)

Examples

contactMatrixAgeSchool(agelims = c(0, 5, 18), agepops = c(500, 1300, 8200),
schoolagegroups = c(2, 2), schoolpops = c(600, 700), schportion = 0.7)

multigroup.vaccine documentation built on Sept. 19, 2026, 1:06 a.m.