View source: R/contactMatrixPropPref.R
| contactMatrixPropPref | R Documentation |
Calculate group contact matrix with proportional mixing and preferential mixing within group
contactMatrixPropPref(popsize, contactrate, ingroup)
popsize |
population size of each group |
contactrate |
overall contact rate of each group |
ingroup |
fraction of each group's contacts that are exclusively in-group |
a square matrix with the contact rate of each group (row) with members of each other group (column)
contactMatrixPropPref(popsize = c(100, 150, 200), contactrate = c(1.1, 1, 0.9),
ingroup = c(0.2, 0.25, 0.22))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.