getCensusDataPath: Get path to example census data file

View source: R/getCensusData.R

getCensusDataPathR Documentation

Get path to example census data file

Description

Returns the path to the example Utah census data CSV file included with the package. This is useful for examples, testing, and when internet access is not available.

Usage

getCensusDataPath()

Value

Character string with the path to the example census CSV file for Utah (FIPS 49)

Examples

# Get path to example Utah census file
utah_csv <- getCensusDataPath()

# Use it with getCensusData

slc_data <- getCensusData(
  state_fips = "49",
  county_name = "Salt Lake County",
  year = 2024,
  csv_path = getCensusDataPath()
)


multigroup.vaccine documentation built on Sept. 19, 2026, 1:06 a.m.