View source: R/getSizeAtTime.R
| getSizeAtTime | R Documentation |
Calculate outbreak size at a given time
getSizeAtTime(time, transmrates, recoveryrate, popsize, initR, initI, initV)
time |
the time at which to calculate the outbreak size |
transmrates |
matrix of group-to-group (column-to-row) transmission rates |
recoveryrate |
inverse of mean infectious period |
popsize |
the population size of each group |
initR |
initial number of each group already infected and removed (included in size result) |
initI |
initial number of each group infectious |
initV |
initial number of each group vaccinated |
a list with totalSize (total cumulative infections) and activeSize (total currently infected) in each group at the specified time
getSizeAtTime(time = 30, transmrates = matrix(0.2, 2 ,2), recoveryrate = 0.3,
popsize = c(100, 150), initR = c(0, 0), initI = c(0, 1), initV = c(10, 10))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.