run_my_app: Runs the shiny app

View source: R/run.R

run_my_appR Documentation

Runs the shiny app

Description

Runs the shiny app

Usage

run_my_app(...)

Arguments

...

Further arguments passed to shiny::shinyAppDir().

Details

The app featured in this package is the one presented in the shiny demo: https://shiny.posit.co/r/getstarted/shiny-basics/lesson1/index.html.

Value

Starts the execution of the app, printing the port on the console.

Examples


# To be executed interactively only
if (interactive()) {
  run_my_app()
}


multigroup.vaccine documentation built on Sept. 19, 2026, 1:06 a.m.