View source: R/getCensusData.R
| getCensusDataPath | R Documentation |
Returns the path to the example Utah census data CSV file included with the package. This is useful for examples, testing, and when internet access is not available.
getCensusDataPath()
Character string with the path to the example census CSV file for Utah (FIPS 49)
# Get path to example Utah census file
utah_csv <- getCensusDataPath()
# Use it with getCensusData
slc_data <- getCensusData(
state_fips = "49",
county_name = "Salt Lake County",
year = 2024,
csv_path = getCensusDataPath()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.