| run_my_app | R Documentation |
Runs the shiny app
run_my_app(...)
... |
Further arguments passed to |
The app featured in this package is the one presented in the shiny demo: https://shiny.posit.co/r/getstarted/shiny-basics/lesson1/index.html.
Starts the execution of the app, printing the port on the console.
# To be executed interactively only
if (interactive()) {
run_my_app()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.